@@ -45,6 +45,10 @@ of the License, or (at your option) any later version.
 #define NETWORK__ONLY_CONNECTED 1
 #define NETWORK__ONLY_DISCONNECTED 2
 
+
+#define SIZE_WIDTH_ALL 800
+#define SIZE_HEIGHT_LINE 40
+
 void desktop_cmd_exec_write_settings (DesktopCmdExec *self, gboolean reset);
 gboolean desktop_cmd_exec_update_content (DesktopCmdExec *self);
 
@@ -81,6 +85,8 @@ struct _DesktopCmdExecPrivate
 
 	guint updNeworkPolicy;
 
+	gdouble widthRatio;
+
 	//Update on timer data
 	guint delaySeconds;
 	guint delayIndex;//index of delaySeconds in the array defined inside "desktop_cmd_exec_settings"
@@ -123,7 +129,7 @@ void desktop_cmd_exec_read_settings ( DesktopCmdExec *self )
 			error = NULL;
 		}
 
-		gint consistencyCheck = -1;
+		guint consistencyCheck = -1;
 		self->priv->c_titles = g_key_file_get_string_list (keyFile, "config", "c_titles", &consistencyCheck ,&error);
 		if (error) {
 			gotAnErrorFlag = TRUE;
@@ -146,6 +152,16 @@ void desktop_cmd_exec_read_settings ( DesktopCmdExec *self )
 		//END
 
 
+		self->priv->widthRatio = g_key_file_get_double (keyFile, "config", "widthRatio", &error);
+		if (error) {
+// 			gotAnErrorFlag = TRUE;
+ 			g_error_free (error);
+ 			error = NULL;
+			g_warning("no widthRatio on key file, assuming 1.0");
+			self->priv->widthRatio = 1.0;
+		}
+
+
 		//BEGIN update policy
 		self->priv->updOnClick = g_key_file_get_boolean (keyFile, "config", "updOnClick", &error);
 		if (error) {
@@ -199,6 +215,8 @@ void desktop_cmd_exec_read_settings ( DesktopCmdExec *self )
 		self->priv->delayIndex = 0;
 		self->priv->delaySeconds = 0;
 
+		self->priv->widthRatio = 1.0;
+
 		self->priv->c_commands = NULL;
 		self->priv->c_titles = NULL;
 		self->priv->c_size = 0;
@@ -225,9 +243,9 @@ void desktop_cmd_exec_write_settings (DesktopCmdExec *self, gboolean reset)
 		self->priv->c_size = 4;
 		gchar * p_titles[] = { "Uptime:", "Battery(%):", "Battery(mAh):", "Boot Reason:", NULL};
 		gchar * p_commands[] = {
-		"uptime | awk 'NF == 7 {print $2 \" \" $3}; NF == 8 {print $2 \" \" $3}; NF == 11 {print $3 \" \" $4 \" \" $5}'",
+		"uptime | awk 'NF == 7 {print $2 \" \" $3; exit 0}; NF == 8 {print $2 \" \" $3; exit 0}; NF == 10 {print $3 \" \" $4 \" \" $5; exit 0}; {print $3 \" \" $4 \" \" $5}'",
 		"hal-device | grep percen | awk '{print $3 \"%\"}'",
-		"hal-device | grep battery.reporting | awk -F. '{print $3}' | awk '$1 == \"current\" { curval = $3}; $1 == \"design\" {print curval \"/\" $3}'",
+		"hal-device | grep battery.reporting | awk -F. '{print $3}' | sort | awk '$1 == \"current\" { current = $3}; $1== \"design\" {print current \"/\" $3}'",
 		"cat /proc/bootreason", NULL};
 
 		//clean possible oldies
@@ -239,19 +257,21 @@ void desktop_cmd_exec_write_settings (DesktopCmdExec *self, gboolean reset)
 		self->priv->c_commands = g_strdupv(p_commands);
 		
 		self->priv->c_current = 2;
+		self->priv->widthRatio = 1.0;
 
 		self->priv->updOnClick = TRUE;
 		self->priv->updOnDesktop = TRUE;
 		self->priv->updNeworkPolicy = NETWORK__UNRELATED;
 		self->priv->delayIndex = 0;
-		
-// 		g_warning("Diiiiid it");
+	
 	}
 	
 	g_key_file_set_string_list(keyFile, "config", "c_titles", (const gchar **)(self->priv->c_titles),self->priv->c_size);
 	g_key_file_set_string_list(keyFile, "config", "c_commands", (const gchar **)(self->priv->c_commands),self->priv->c_size);
 	g_key_file_set_integer(keyFile, "config", "c_current", self->priv->c_current);
 
+	g_key_file_set_double (keyFile, "config", "widthRatio", self->priv->widthRatio);
+
 	g_key_file_set_boolean (keyFile, "config", "updOnClick", self->priv->updOnClick);
 	g_key_file_set_boolean (keyFile, "config", "updOnDesktop", self->priv->updOnDesktop);
 	g_key_file_set_integer (keyFile, "config", "delayIndex", self->priv->delayIndex);
@@ -365,6 +385,12 @@ void desktop_cmd_exec_content_create (DesktopCmdExec *self)
 }
 
 
+gboolean desktop_cmd_exec_resize_hack(DesktopCmdExec *self)
+{
+	gtk_widget_set_size_request (GTK_WIDGET (self), (int)(SIZE_WIDTH_ALL*self->priv->widthRatio), SIZE_HEIGHT_LINE);
+	gtk_window_resize (GTK_WINDOW (self), (int)(SIZE_WIDTH_ALL*self->priv->widthRatio), SIZE_HEIGHT_LINE);
+	return FALSE;
+}
 
 gboolean desktop_cmd_exec_update_content (DesktopCmdExec *self)
 {
@@ -376,7 +402,6 @@ gboolean desktop_cmd_exec_update_content (DesktopCmdExec *self)
 	if(self->priv->updNeworkPolicy == NETWORK__ONLY_DISCONNECTED && self->priv->isConnected == TRUE)
 		return FALSE;
 
-
 	FILE *fp;
 	gchar line[256];
 	gchar *result;
@@ -540,22 +565,31 @@ static void desktop_cmd_exec_init (DesktopCmdExec *self)
 	hd_home_plugin_item_set_settings (&self->parent, TRUE);
 	g_signal_connect (&self->parent, "show-settings", G_CALLBACK (desktop_cmd_exec_settings), self);
 
-	gtk_window_set_default_size (GTK_WINDOW (self), 800, 40);
+	gtk_window_set_default_size (GTK_WINDOW (self), SIZE_WIDTH_ALL, SIZE_HEIGHT_LINE);
 	
 	self->priv->homeWidget = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (self), self->priv->homeWidget);
 	gtk_widget_show (self->priv->homeWidget);
 
-	GdkGeometry hints;
-	hints.min_width = 800;
-	hints.min_height = 40;
-	hints.max_width = 800;
-	hints.max_height = 40;
-	gtk_window_set_geometry_hints (GTK_WINDOW (self), self->priv->homeWidget, &hints, GDK_HINT_MIN_SIZE | GDK_HINT_MAX_SIZE);
-	
 	desktop_cmd_exec_read_settings (self);
-	gtk_widget_set_size_request (GTK_WIDGET (self), 800, 40);
-	gtk_window_resize (GTK_WINDOW (self), 800, 40);
+	
+	GdkGeometry hints;
+
+	hints.min_width = (int)(SIZE_WIDTH_ALL*0.05);
+	hints.min_height = SIZE_HEIGHT_LINE;
+	hints.max_width = (int)(SIZE_WIDTH_ALL);
+	hints.max_height = SIZE_HEIGHT_LINE;
+
+	gtk_window_set_geometry_hints (GTK_WINDOW (self), self->priv->homeWidget, &hints, GDK_HINT_MIN_SIZE | GDK_HINT_MAX_SIZE);
+
+	gtk_widget_set_size_request (GTK_WIDGET (self), (int)(SIZE_WIDTH_ALL*0.118), SIZE_HEIGHT_LINE);
+	gtk_window_resize (GTK_WINDOW (self), (int)(SIZE_WIDTH_ALL*0.118), SIZE_HEIGHT_LINE);
+
+	g_timeout_add (500, (GSourceFunc)desktop_cmd_exec_resize_hack, self);
+
+// 	gtk_widget_set_size_request (GTK_WIDGET (self), SIZE_WIDTH_ALL, SIZE_HEIGHT_LINE);
+// 	gtk_window_resize (GTK_WINDOW (self), (int)(SIZE_WIDTH_ALL*self->priv->widthRatio), SIZE_HEIGHT_LINE);
+// 	gtk_window_resize (GTK_WINDOW (self), SIZE_WIDTH_ALL, SIZE_HEIGHT_LINE);
 
 	
 	desktop_cmd_exec_content_create (self);
@@ -622,6 +656,25 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 		gtk_container_add (GTK_CONTAINER (content_area), cmdSelector);
 		//END
 
+		//BEGIN
+		//layout opts
+
+		GtkWidget *widthBox = gtk_hbox_new (FALSE, 0);
+
+		GtkWidget *widthLabel = gtk_label_new ("Width:");
+		gtk_misc_set_alignment (GTK_MISC (widthLabel), 0, 0.5);
+		gtk_misc_set_padding (GTK_MISC (widthLabel), HILDON_MARGIN_DOUBLE, 0);
+		gtk_size_group_add_widget (group, widthLabel);
+
+		GtkWidget * widthSelect = gtk_hscale_new_with_range ((gdouble)0.05, (gdouble)1.0, (gdouble)0.05);
+		gtk_range_set_value(GTK_RANGE(widthSelect), self->priv->widthRatio);
+		
+		gtk_box_pack_start (GTK_BOX (widthBox), widthLabel, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (widthBox), widthSelect, TRUE, TRUE, 0);
+
+		gtk_container_add (GTK_CONTAINER (content_area), widthBox);
+		//END
+
 		//BEGIN Update Policy
 		GtkWidget *updPolicyLabel = gtk_label_new ("");
 		gtk_label_set_markup (GTK_LABEL (updPolicyLabel), "<small>Update Policy:</small>");
@@ -693,6 +746,13 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 			{
 				self->priv->c_current = (gint) cmdSel;
 			}
+
+
+			self->priv->widthRatio = gtk_range_get_value(GTK_RANGE(widthSelect));
+
+			gtk_widget_set_size_request (GTK_WIDGET (self), (int)(SIZE_WIDTH_ALL*self->priv->widthRatio), SIZE_HEIGHT_LINE);
+			gtk_window_resize (GTK_WINDOW (self), (int)(SIZE_WIDTH_ALL*self->priv->widthRatio), SIZE_HEIGHT_LINE);
+			
 			self->priv->updOnClick = hildon_check_button_get_active (HILDON_CHECK_BUTTON (checkBtClick));
 			self->priv->updOnDesktop = hildon_check_button_get_active (HILDON_CHECK_BUTTON (checkBtDesktop));
 			
@@ -856,12 +916,10 @@ void DelCommand(DesktopCmdExec *self, int index)
 {
 	gchar ** newTitles = malloc( sizeof(gchar*)*(self->priv->c_size) );
 	gchar ** newCommands = malloc( sizeof(gchar*)*(self->priv->c_size) );
-	g_warning("mallocated %d", self->priv->c_size);
 
 	int i;
 	for(i=0;i<self->priv->c_size;i++)
 	{
-		g_warning("gathering..%d", i);
 		//index is the delete target
 		if(i < index)
 		{
@@ -872,18 +930,14 @@ void DelCommand(DesktopCmdExec *self, int index)
 		{
 			newTitles[i-1] = g_strdup(self->priv->c_titles[i]);
 			newCommands[i-1] = g_strdup(self->priv->c_commands[i]);
-			g_warning("wrote at %d",i-1);
 		}
 	}
-	g_warning("ok.. no prob");
 	newTitles[self->priv->c_size-1] = NULL;
 	newCommands[self->priv->c_size-1] = NULL;
-	g_warning("nulled %d", self->priv->c_size-1);
 
 	//clear old
 	g_strfreev(self->priv->c_titles);
 	g_strfreev(self->priv->c_commands);
-	g_warning("cleared ok");
 
 	//assign new
 	self->priv->c_titles = newTitles;
@@ -891,7 +945,7 @@ void DelCommand(DesktopCmdExec *self, int index)
 
 	self->priv->c_current = 0;
 	self->priv->c_size -= 1;//decrement size
-	g_warning("end of del");
+
 }
 
 guint GetSeconds(guint index)
