@@ -1,3 +1,18 @@
+/*
+
+desktop-cmd-exec.h - Desktop Command Execution Widget
+
+Copyright (c) 2010 cpscotti (Clovis Peruchi Scotti)
+
+This program is free software; you can redistribute it and/or
+modify it under the terms of the GNU General Public License
+as published by the Free Software Foundation; either version 2
+of the License, or (at your option) any later version.
+
+[cpscotti, roboscotti, scotti@ieee.org]
+
+*/
+
 #ifndef _DESKTOP_CMD_EXEC
 #define _DESKTOP_CMD_EXEC
 
